@@ -1,12 +1,17 @@
 from typing import Optional, List, Union
+import logging
 from hein_robots.robotics import Location, Twist, Wrench, Cartesian, Orientation, Units, Frame
 from hein_robots.base.actuators import Actuator
 from hein_robots.base.grippers import Gripper
 
+logger = logging.getLogger(__name__)
+
 
 class RobotArm:
     def __init__(self, default_velocity: float = 250, max_velocity: float = 500, position_units: str = Units.MILLIMETERS,
                  gripper_default_velocity: float = 0.5, gripper_default_force: float = 0.5):
+        self.logger = logger.getChild(self.__class__.__name__)
+
         self._position_units = position_units
         self._default_velocity = default_velocity
         self._max_velocity = max_velocity
@@ -34,6 +39,7 @@ class RobotArm:
         if value < 0 or value > self.max_velocity:
             raise RobotArmInvalidVelocityError(f'Invalid velocity: {value} m/s, must be less than {self.max_velocity} m/s')
 
+        self.logger.debug(f'default_velocity = {value}')
         self._default_velocity = value
 
     @property
@@ -81,6 +87,7 @@ class RobotArm:
         if velocity < 0 or velocity > 1:
             raise RobotArmGripperInvalidVelocityError(f'Invalid velocity, must be float between 0 and 1: {velocity}')
 
+        self.logger.debug(f'gripper_default_velocity = {velocity}')
         self._gripper_default_velocity = velocity
 
     @property
@@ -92,6 +99,7 @@ class RobotArm:
         if force < 0 or force > 1:
             raise RobotArmGripperInvalidForceError(f'Invalid force, must be float between 0 and 1: {force}')
 
+        self.logger.debug(f'gripper_default_force = {force}')
         self._gripper_default_force = force
 
     @property
